import smtplib
import logging
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from pydantic import BaseModel, Field

logger = logging.getLogger(__name__)


class MailSender(BaseModel):
    """Classe représentant un objet permettant d'envoyer un e-mail via SMTP."""
    smtp_server: str
    sender_email: str
    smtp_port: int = Field(default=25)
    login_auth: str = Field(default='')
    password_auth: str = Field(default='', repr=False)

    def send(self, dest_mail: str, subject: str, cc: str = '', bcc: str = '', message: str = '',
             type_message: str = 'plain') -> None:
        """Envoie un e-mail au destinataire spécifié.

        Args:
            dest_mail (str): L'adresse e-mail du destinataire
            subject (str): Le sujet de l'e-mail
            cc (str) : adresse copie
            bcc (str) : adresse copie invisible
            message (str): Le contenu du message de l'e-mail
            type_message (str): type du message à envoyer ('plain' ou 'html')

        Raises:
            Exception: Si une erreur se produit lors de l'envoi de l'e-mail.
        """
        msg = MIMEMultipart()
        msg["From"] = self.sender_email
        msg["To"] = dest_mail
        msg["Cc"] = cc
        msg["Bcc"] = bcc
        msg["Subject"] = subject

        msg.attach(MIMEText(message, type_message, 'utf-8'))

        try:
            with smtplib.SMTP(self.smtp_server, self.smtp_port) as server:
                if self.login_auth and self.password_auth:
                    server.login(self.login_auth, self.password_auth)
                server.send_message(msg)
                logger.info("E-mail envoyé avec succès")
        except Exception as e:
            logger.debug("Erreur lors de l'envoi de l'e-mail:", str(e))